==> ngx-text-highlight-0.1.1.tgz: package/index.js <==
import { Component, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgHighlightComponent = (function () {
    function NgHighlightComponent() {
        this.splitFlag = '';
        this.matchFlag = '';
        this._customClass = '';
        this.caseSensitive = false;
        this._customClass = '';
    }
    Object.defineProperty(NgHighlightComponent.prototype, "content", {
        get: /**
         * @return {?}
         */
        function () { return this._content; },
        set: /**
         * @param {?} content
         * @return {?}
         */
        function (content) {
            this._content = content;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgHighlightComponent.prototype, "searchTerm", {
        get: /**
         * @return {?}
         */
        function () { return this._searchTerm; },
        set: /**
         * @param {?} searchTerm
         * @return {?}
         */
        function (searchTerm) {
            this._searchTerm = searchTerm;
            this.filterText();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgHighlightComponent.prototype, "customClass", {
        get: /**
         * @return {?}
         */
        function () { return this._customClass; },
        set: /**
         * @param {?} customClass
         * @return {?}
         */
        function (customClass) {
            console.log(customClass);
            this._customClass = customClass;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgHighlightComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () { };
    /**
     * @return {?}
     */
    NgHighlightComponent.prototype.filterText = /**
     * @return {?}
     */
    function () {
        if (!this.caseSensitive) {
            this.splitFlag = 'i';
            this.matchFlag = 'gi';
        }
        else {
            this.splitFlag = '';
            this.matchFlag = 'g';
        }
        console.log(this._customClass);
        this.patterForMatch = new RegExp(this._searchTerm, this.matchFlag);
        this.patternForSplit = new RegExp(this._searchTerm, this.splitFlag);
        this.matchedContent = this._content.match(this.patterForMatch);
        this.separatedContent = this._content.split(this.patternForSplit);
    };
    /**
     * @return {?}
     */
    NgHighlightComponent.prototype.getCssClass = /**
     * @return {?}
     */
    function () {
        if (this._customClass.length > 0) {
            return this._customClass;
        }
        else {
            return 'highlight';
        }
    };
    NgHighlightComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ng-highlight',
                    template: "<div *ngIf=\"separatedText?.length === 1;then actualTemplate;else highlightedTemplate\" > </div> <ng-template #actualTemplate class=\"blue-highlight\"> {{content}} </ng-template> <ng-template #highlightedTemplate > <ng-template ngFor let-part [ngForOf]=\"separatedContent\" let-i=\"index\">{{part}}<!-- --><span *ngIf=\"i<matchedContent.length\" class=\"padding\" [ngClass]=\"getCssClass()\" >{{matchedContent[i]}}</span><!-- --></ng-template> </ng-template>",
                    styles: [".highlight{ background: yellow; } .padding{ padding: 0; }"]
                },] },
    ];
    /** @nocollapse */
    NgHighlightComponent.ctorParameters = function () { return []; };
    NgHighlightComponent.propDecorators = {
        "content": [{ type: Input, args: ['content',] },],
        "searchTerm": [{ type: Input, args: ['searchTerm',] },],
        "caseSensitive": [{ type: Input },],
        "customClass": [{ type: Input, args: ['customClass',] },],
    };
    return NgHighlightComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgHighlightModule = (function () {
    function NgHighlightModule() {
    }
    /**
     * @return {?}
     */
    NgHighlightModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: NgHighlightModule
        };
    };
    NgHighlightModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        NgHighlightComponent
                    ],
                    exports: [
                        NgHighlightComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    NgHighlightModule.ctorParameters = function () { return []; };
    return NgHighlightModule;
}());

export { NgHighlightModule, NgHighlightComponent };

==> ngx-text-highlight-0.1.2.tgz: package/index.js <==
import { Component, Input, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgHighlightComponent = (function () {
    function NgHighlightComponent() {
        this.splitFlag = '';
        this.matchFlag = '';
        this._customClass = '';
        this.caseSensitive = false;
        this._customClass = '';
    }
    Object.defineProperty(NgHighlightComponent.prototype, "content", {
        get: /**
         * @return {?}
         */
        function () { return this._content; },
        set: /**
         * @param {?} content
         * @return {?}
         */
        function (content) {
            this._content = content;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgHighlightComponent.prototype, "searchTerm", {
        get: /**
         * @return {?}
         */
        function () { return this._searchTerm; },
        set: /**
         * @param {?} searchTerm
         * @return {?}
         */
        function (searchTerm) {
            this._searchTerm = searchTerm;
            this.filterText();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgHighlightComponent.prototype, "customClass", {
        get: /**
         * @return {?}
         */
        function () { return this._customClass; },
        set: /**
         * @param {?} customClass
         * @return {?}
         */
        function (customClass) {
            console.log(customClass);
            this._customClass = customClass;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgHighlightComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () { };
    /**
     * @return {?}
     */
    NgHighlightComponent.prototype.filterText = /**
     * @return {?}
     */
    function () {
        if (!this.caseSensitive) {
            this.splitFlag = 'i';
            this.matchFlag = 'gi';
        }
        else {
            this.splitFlag = '';
            this.matchFlag = 'g';
        }
        console.log(this._customClass);
        this.patterForMatch = new RegExp(this._searchTerm, this.matchFlag);
        this.patternForSplit = new RegExp(this._searchTerm, this.splitFlag);
        this.matchedContent = this._content.match(this.patterForMatch);
        this.separatedContent = this._content.split(this.patternForSplit);
    };
    /**
     * @return {?}
     */
    NgHighlightComponent.prototype.getCssClass = /**
     * @return {?}
     */
    function () {
        if (this._customClass.length > 0) {
            return this._customClass;
        }
        else {
            return 'highlight';
        }
    };
    NgHighlightComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ng-highlight',
                    template: "<div *ngIf=\"separatedContent?.length === 1;then actualTemplate;else highlightedTemplate\" > </div> <ng-template #actualTemplate class=\"blue-highlight\"> {{content}} </ng-template> <ng-template #highlightedTemplate > <ng-template ngFor let-part [ngForOf]=\"separatedContent\" let-i=\"index\">{{part}}<!-- --><span *ngIf=\"i<matchedContent.length\" class=\"padding\" [ngClass]=\"getCssClass()\" >{{matchedContent[i]}}</span><!-- --></ng-template> </ng-template>",
                    styles: [".highlight{ background: yellow; } .padding{ padding: 0; }"]
                },] },
    ];
    /** @nocollapse */
    NgHighlightComponent.ctorParameters = function () { return []; };
    NgHighlightComponent.propDecorators = {
        "content": [{ type: Input, args: ['content',] },],
        "searchTerm": [{ type: Input, args: ['searchTerm',] },],
        "caseSensitive": [{ type: Input },],
        "customClass": [{ type: Input, args: ['customClass',] },],
    };
    return NgHighlightComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var NgHighlightModule = (function () {
    function NgHighlightModule() {
    }
    /**
     * @return {?}
     */
    NgHighlightModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: NgHighlightModule
        };
    };
    NgHighlightModule.decorators = [
        { type: NgModule, args: [{
                    imports: [
                        CommonModule
                    ],
                    declarations: [
                        NgHighlightComponent
                    ],
                    exports: [
                        NgHighlightComponent
                    ]
                },] },
    ];
    /** @nocollapse */
    NgHighlightModule.ctorParameters = function () { return []; };
    return NgHighlightModule;
}());

export { NgHighlightModule, NgHighlightComponent };
